@@ -65,10 +65,12 @@ footer() {
 	echo "
 		<hr>
 		<div style=\"font-size:0.5em;\">
-			<img style=\"height:30px; width:60px; float:left;\" src=\"$imagepath\" alt=\"Splash Page: For access to the Internet.\">
-			&copy; The openNDS Project 2015 - $year<br>
-			openNDS $version
-			<br><br>
+			<br>
+			<img style=\"height:60px; width:60px; float:left;\" src=\"$imagepath\" alt=\"Splash Page: For access to the Internet.\">
+			&copy; Portal: BlueWave Projects and Services 2015 - $year<br>
+			<br>
+			Portal Version: $version
+			<br><br><br><br>
 		</div>
 		</div>
 		</div>
@@ -79,8 +81,6 @@ footer() {
 	exit 0
 }
 
-
-
 click_to_continue() {
 	# This is the simple click to continue splash page with no client validation.
 	# The client is however required to accept the terms of service.
