@@ -218,6 +218,13 @@ else
 	# Build the log entry:
 	log_entry="method=$1, clientmac=$2, bytes_incoming=$3, bytes_outgoing=$4, session_start=$5, session_end=$6, token=$7, custom=$customdata"
 
+	action=$(echo "$1" | awk -F"_" '{printf("%s", $2)}')
+
+	# Send the deauth log to FAS if fas_secure_enabled = 3, if not =3 library call does nothing
+	if [ "$action" = "deauth" ]; then
+		returned=$(/usr/lib/opennds/libopennds.sh "send_to_fas_deauthed" "$log_entry")
+	fi
+
 fi
 
 # In the case of ThemeSpec, get the client id information from the cid database
@@ -274,6 +281,11 @@ write_log
 # Set length of session in seconds (eg 24 hours is 86400 seconds - if set to 0 then defaults to global or FAS sessiontimeout value):
 session_length=0
 
+custom=$8
+custom=$(/usr/lib/opennds/unescape.sh -url "$custom")
+custom=$(ndsctl b64decode "$custom")
+session_length=$(echo "$custom" | awk -F"session_length=" '{printf "%d", $2}')
+
 # Set Rate and Quota values for the client
 # The session length, rate and quota values are determined globaly or by FAS/PreAuth on a per client basis.
 # rates are in kb/s, quotas are in kB. Setting to 0 means no limit
